@@ -29,9 +29,6 @@ pub enum WorkflowError {
     #[error(transparent)]
     InvalidFrontMatterYaml { source: NoteError },
 
-    #[error(transparent)]
-    InvalidStdinYaml { source: NoteError },
-
     #[error(transparent)]
     InvalidClipboardYaml { source: NoteError },
 
@@ -41,9 +38,6 @@ pub enum WorkflowError {
     #[error(transparent)]
     FileExtNotRegistered { source: NoteError },
 
-    #[error(transparent)]
-    NoHyperlinkFound { source: NoteError },
-
     #[error(transparent)]
     Note {
         #[from]
@@ -229,7 +223,10 @@ pub enum NoteError {
          \t{field_name}: \"My note\"\n\
          \t---\n\
          \tsome text\n\
-         \t~~~~~~~~~~~~~~"
+         \t~~~~~~~~~~~~~~\n\
+         \n\
+         Please correct the front matter if this is supposed \
+         to be a Tp-Note file. Ignore otherwise."
     )]
     MissingFrontMatterField { field_name: String },
 
@@ -269,7 +266,10 @@ pub enum NoteError {
          \t{compulsory_field}: \"My note\"\n\
          \t---\n\
          \tsome text\n\
-         \t~~~~~~~~~~~~~~"
+         \t~~~~~~~~~~~~~~\n\
+         \n\
+         Please correct the front matter if this is supposed \
+         to be a Tp-Note file. Ignore otherwise."
     )]
     MissingFrontMatter { compulsory_field: String },
 
@@ -325,11 +325,6 @@ pub enum NoteError {
         source: core::str::Utf8Error,
     },
 
-    /// Remedy: make sure that the hyperlink is formatted in
-    /// a supported markup language.
-    #[error("No hyperlink found in input stream.")]
-    NoHyperlinkFound,
-
     #[error(transparent)]
     Io(#[from] std::io::Error),
 }
