@@ -15,14 +15,9 @@ use crate::settings::CLIPBOARD;
 use crate::settings::LAUNCH_EDITOR;
 use crate::settings::LAUNCH_VIEWER;
 #[cfg(feature = "read-clipboard")]
-use crate::settings::RUNS_ON_CONSOLE;
 use crate::settings::STDIN;
 #[cfg(feature = "viewer")]
 use crate::viewer::launch_viewer_thread;
-#[cfg(feature = "read-clipboard")]
-use clipboard::ClipboardContext;
-#[cfg(feature = "read-clipboard")]
-use clipboard::ClipboardProvider;
 use std::env;
 use std::fs;
 #[cfg(not(target_family = "windows"))]
@@ -52,9 +47,6 @@ fn synchronize_filename(path: &Path) -> Result<PathBuf, WorkflowError> {
         Err(e) if matches!(e, NoteError::InvalidFrontMatterYaml { .. }) => {
             return Err(WorkflowError::InvalidFrontMatterYaml { source: e })
         }
-        Err(e) if matches!(e, NoteError::InvalidStdinYaml { .. }) => {
-            return Err(WorkflowError::InvalidStdinYaml { source: e })
-        }
         Err(e) if matches!(e, NoteError::InvalidClipboardYaml { .. }) => {
             return Err(WorkflowError::InvalidClipboardYaml { source: e })
         }
@@ -64,9 +56,6 @@ fn synchronize_filename(path: &Path) -> Result<PathBuf, WorkflowError> {
         Err(e) if matches!(e, NoteError::FileExtNotRegistered { .. }) => {
             return Err(WorkflowError::FileExtNotRegistered { source: e })
         }
-        Err(e) if matches!(e, NoteError::NoHyperlinkFound { .. }) => {
-            return Err(WorkflowError::NoHyperlinkFound { source: e })
-        }
         Err(e) => return Err(e.into()),
     };
 
@@ -303,11 +292,8 @@ pub fn run() -> Result<PathBuf, WorkflowError> {
             if (matches!(e, WorkflowError::InvalidFrontMatterYaml { .. })
                 || matches!(e, WorkflowError::MissingFrontMatter { .. })
                 || matches!(e, WorkflowError::MissingFrontMatterField { .. })
-                || matches!(e, WorkflowError::InvalidStdinYaml { .. })
-                || matches!(e, WorkflowError::InvalidClipboardYaml { .. })
                 || matches!(e, WorkflowError::SortTagVarInvalidChar { .. })
-                || matches!(e, WorkflowError::FileExtNotRegistered { .. })
-                || matches!(e, WorkflowError::NoHyperlinkFound { .. }))
+                || matches!(e, WorkflowError::FileExtNotRegistered { .. }))
                 && !ARGS.batch
                 && ARGS.export.is_none()
             {
@@ -321,22 +307,10 @@ pub fn run() -> Result<PathBuf, WorkflowError> {
 
                 if launch_viewer || missing_header {
                     // Inform user when `--debug warn`, then continue workflow.
-                    log::warn!(
-                        "{}\n\
-                        \n\
-                        Please correct the front matter if this is supposed \
-                        to be a Tp-Note file. Ignore otherwise.",
-                        e,
-                    );
+                    log::warn!("{}", e,);
                 } else {
                     // Inform user, then continue workflow.
-                    log::error!(
-                        "{}\n\
-                        \n\
-                        Please correct the front matter if this is supposed \
-                        to be a Tp-Note file. Ignore otherwise.",
-                        e,
-                    );
+                    log::error!("{}", e,);
                 };
             } else {
                 // This is a fatal error, so we quit.
@@ -385,15 +359,6 @@ pub fn run() -> Result<PathBuf, WorkflowError> {
                 }
             }
         };
-
-        // Delete clipboard content.
-        #[cfg(feature = "read-clipboard")]
-        if CFG.clipboard.read_enabled && CFG.clipboard.empty_enabled && !*RUNS_ON_CONSOLE {
-            let ctx: Option<ClipboardContext> = ClipboardProvider::new().ok();
-            if let Some(mut ctx) = ctx {
-                ctx.set_contents("".to_owned()).unwrap_or_default();
-            };
-        }
     } else {
         #[cfg(feature = "viewer")]
         if let Some(jh) = viewer_join_handle {
